@@ -32,6 +32,8 @@ CMOR_REPLACE_3
 CMOR_PRESERVE_4
 CMOR_APPEND_4
 CMOR_REPLACE_4
+GLOBAL_ATT_HISTORYTMPL
+CMOR_DEFAULT_HISTORY_TEMPLATE
 """
 
 for att in atts.split():
