@@ -45,7 +45,7 @@ CONTAINS
   
     plevs = (/100000., 92500., 85000., 70000.,&
        60000., 50000., 40000., 30000., 25000., 20000.,&
-       15000., 10000., 7000., 5000., 3000., 2000., 1000. /)
+       15000., 10000., 7000., 5000., 3000., 2000., 1000., 500., 100. /)
     RETURN
   END SUBROUTINE read_coords
 
@@ -117,7 +117,7 @@ PROGRAM karls_test
   INTEGER, PARAMETER :: ntimes = 2    ! number of time samples to process
   INTEGER, PARAMETER :: lon = 4       ! number of longitude grid cells  
   INTEGER, PARAMETER :: lat = 3       ! number of latitude grid cells
-  INTEGER, PARAMETER :: lev2 = 17       ! number of standard pressure levels
+  INTEGER, PARAMETER :: lev2 = 19       ! number of standard pressure levels
   INTEGER, PARAMETER :: lev = 5       ! number of standard pressure levels
   INTEGER, PARAMETER :: n2d = 4       ! number of IPCC Table A1a fields to be
                                       !     output.
@@ -226,34 +226,12 @@ PROGRAM karls_test
   !   experiment conditions, and provide information to be included as 
   !   attributes in all CF-netCDF files written as part of this dataset.
 
-  error_flag = cmor_dataset(                                   &
-       outpath='Test',                                         &
-       experiment_id='abrupt 4XCO2',           &
-       institution=                                            &
-       'GICC (Generic International Climate Center, ' //       &
-       'Geneva, Switzerland)',                                 &
-       source='GICCM1 (2002): ' //                             &
-       'atmosphere:  GICAM3 (gicam_0_brnchT_itea_2, T63L32); '// &
-       'ocean: MOM (mom3_ver_3.5.2, 2x3L15); '             //  &
-       'sea ice: GISIM4; land: GILSM2.5',                      &
-       calendar='360_day',                                      &
-       realization=1,                                          &
-       history='Output from archive/giccm_03_std_2xCO2_2256.', &
-       comment='Equilibrium reached after 30-year spin-up ' // &
-       'after which data were output starting with nominal '// &
-       'date of January 2030',                                 &
-       references='Model described by Koder and Tolkien ' //   &
-       '(J. Geophys. Res., 2001, 576-591).  Also '        //   &
-       'see http://www.GICC.su/giccm/doc/index.html '     //   &
-       ' 2XCO2 simulation described in Dorkey et al. '    //   &
-       '(Clim. Dyn., 2003, 323-357.)',&
-       model_id='GICCM1',forcing='TO',contact="Barry Bonds",&
-       parent_experiment_rip="N/A",parent_experiment_id="N/A",branch_time=bt,institute_id="PCMDI")
+  error_flag = cmor_dataset_json("common_user_input.json")
   
   !  Define all axes that will be needed
 
   iz =  cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='Tables/CMIP6_Amon.json',    &
        table_entry='height2m',       &
        units='m',                    &  
        length=1,                     &
@@ -261,7 +239,7 @@ PROGRAM karls_test
 print*, 'iz = ', iz
   
   ilat = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='Tables/CMIP6_Amon.json',    &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -269,14 +247,14 @@ print*, 'iz = ', iz
        cell_bounds=bnds_lat)        
       
   ilon = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='Tables/CMIP6_Amon.json',    &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
        coord_vals=alons,             &
        cell_bounds=bnds_lon)      
   ilat2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',    &
+       table='Tables/CMIP6_Lmon.json',    &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -284,17 +262,17 @@ print*, 'iz = ', iz
        cell_bounds=bnds_lat)        
       
   ilon2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',    &
+       table='Tables/CMIP6_Lmon.json',    &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
        coord_vals=alons,             &
        cell_bounds=bnds_lon)      
         
-  print*, 'plevs:',plevs
+  print*, 'plev19:',plevs
   ipres = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
-       table_entry='plevs',       &
+       table='Tables/CMIP6_Amon.json',    &
+       table_entry='plev19',       &
        units='Pa',                   &
        length=lev2,                   &
        coord_vals=plevs)
@@ -304,13 +282,13 @@ print*, 'iz = ', iz
   !   cmor_write (later, below).
 
   itim = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='Tables/CMIP6_Amon.json',    &
        table_entry='time',           &
        units='days since 2030-1-1',  &
        length=ntimes,                &
        interval='1 month')
   itim2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',    &
+       table='Tables/CMIP6_Lmon.json',    &
        table_entry='time',           &
        units='days since 2030-1-1',  &
        length=ntimes,                &
@@ -322,7 +300,7 @@ print*, 'iz = ', iz
   zlev_bnds=(/ 0.,.2, .42, .62, .8, 1. /)
 
   ilev = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='Tables/CMIP6_Amon.json',    &
        table_entry='standard_hybrid_sigma',       &
        length=lev,                   &
        units = '1', &
@@ -367,7 +345,7 @@ print*, 'iz = ', iz
   !    (appearing in IPCC table A1c)
 
   var3d_ids(1) = cmor_variable(    &
-       table='Tables/CMIP5_Amon',  &
+       table='Tables/CMIP6_Amon.json',  &
        table_entry=entry3d(1),     &
        units=units3d(1),           &
        axis_ids=(/ ilon, ilat, ilev, itim /),  &
@@ -379,7 +357,7 @@ print*, 'iz = ', iz
   
   DO m=2,n3d
      var3d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',  &
+          table='Tables/CMIP6_Amon.json',  &
           table_entry=entry3d(m),     &
           units=units3d(m),           &
           axis_ids=(/ ilon, ilat, ipres, itim /), &
@@ -396,17 +374,17 @@ print*, 'iz = ', iz
      IF (m.eq.2) then
 !!$
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',  &
+          table='Tables/CMIP6_Amon.json',  &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
-          axis_ids=(/ ilon, iz, ilat, itim  /), &
+          axis_ids=(/ ilon,  ilat, itim  /), &
           missing_value=1.0e28,       &
           positive=positive2d(m),     &
           original_name=varin2d(m))   
 
   else if (m.eq.3) then
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Lmon',  &
+          table='Tables/CMIP6_Lmon.json',  &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
           axis_ids=(/ ilon2, ilat2, itim2 /), &
@@ -415,7 +393,7 @@ print*, 'iz = ', iz
           original_name=varin2d(m))   
   else
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',  &
+          table='Tables/CMIP6_Amon.json',  &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
           axis_ids=(/ ilon, ilat, itim /), &
