@@ -213,34 +213,12 @@ PROGRAM ipcc_test_code
   !   experiment conditions, and provide information to be included as 
   !   attributes in all CF-netCDF files written as part of this dataset.
 
-  error_flag = cmor_dataset(                                   &
-       outpath='Test',                                         &
-       experiment_id='abrupt 4XCO2',           &
-       institution=                                            &
-       'GICC (Generic International Climate Center, ' //       &
-       'Geneva, Switzerland)',                                 &
-       source='GICCM1 (2002): ' //                             &
-       'atmosphere:  GICAM3 (gicam_0_brnchT_itea_2, T63L32); '// &
-       'ocean: MOM (mom3_ver_3.5.2, 2x3L15); '             //  &
-       'sea ice: GISIM4; land: GILSM2.5',                      &
-       calendar='360_day',                                      &
-       realization=1,                                          &
-       history='Output from archive/giccm_03_std_2xCO2_2256.', &
-       comment='Equilibrium reached after 30-year spin-up ' // &
-       'after which data were output starting with nominal '// &
-       'date of January 2030',                                 &
-       references='Model described by Koder and Tolkien ' //   &
-       '(J. Geophys. Res., 2001, 576-591).  Also '        //   &
-       'see http://www.GICC.su/giccm/doc/index.html '     //   &
-       ' 2XCO2 simulation described in Dorkey et al. '    //   &
-       '(Clim. Dyn., 2003, 323-357.)', model_id="GICCM1", &
-       forcing='TO',contact="Barry Bonds",institute_id="PCMDI",&
-       parent_experiment_rip="N/A",parent_experiment_id="N/A",branch_time=bt)
+  error_flag = cmor_dataset_json("Test/common_user_input.json")
   
   !  Define all axes that will be needed
 
   ilat = cmor_axis(  &
-       table='Tables/CMIP5_3hr',    &
+       table='Tables/CMIP6_3hr.json',    &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -248,7 +226,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lat)        
       
   ilon = cmor_axis(  &
-       table='Tables/CMIP5_3hr',    &
+       table='Tables/CMIP6_3hr.json',    &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
@@ -256,7 +234,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lon)      
         
 !!$  ipres = cmor_axis(  &
-!!$       table='Tables/CMIP5_3hr',    &
+!!$       table='Tables/CMIP6_3hr.json',    &
 !!$       table_entry='pressure',       &
 !!$       units='Pa',                   &
 !!$       length=lev,                   &
@@ -267,14 +245,14 @@ PROGRAM ipcc_test_code
   !   cmor_write (later, below).
 
   itim = cmor_axis(  &
-       table='Tables/CMIP5_3hr',    &
+       table='Tables/CMIP6_3hr.json',    &
        table_entry='time',           &
        units='hours since 2030-1-1',  &
        length=ntimes,                &
        interval='3 hours')
 
   itim1 = cmor_axis(  &
-       table='Tables/CMIP5_3hr',    &
+       table='Tables/CMIP6_3hr.json',    &
        table_entry='time1',           &
        units='hours since 2030-1-1',  &
        length=ntimes)
@@ -285,7 +263,7 @@ PROGRAM ipcc_test_code
 !!$  zlev_bnds=(/ 0.,.2, .42, .62, .8, 1. /)
 !!$
 !!$  ilev = cmor_axis(  &
-!!$       table='Tables/CMIP5_3hr',    &
+!!$       table='Tables/CMIP6_3hr.json',    &
 !!$       table_entry='standard_hybrid_sigma',       &
 !!$       length=lev,                   &
 !!$       coord_vals=zlevs,             &
@@ -329,7 +307,7 @@ PROGRAM ipcc_test_code
 !!$  !    (appearing in IPCC table A1c)
 !!$
 !!$  var3d_ids(1) = cmor_variable(    &
-!!$       table='Tables/CMIP5_3hr',  &
+!!$       table='Tables/CMIP6_3hr.json',  &
 !!$       table_entry=entry3d(1),     &
 !!$       units=units3d(1),           &
 !!$       axis_ids=(/ ilon, ilat, ilev, itim /),  &
@@ -341,7 +319,7 @@ PROGRAM ipcc_test_code
 !!$  
 !!$  DO m=2,n3d
 !!$     var3d_ids(m) = cmor_variable(    &
-!!$          table='Tables/CMIP5_3hr',  &
+!!$          table='Tables/CMIP6_3hr.json',  &
 !!$          table_entry=entry3d(m),     &
 !!$          units=units3d(m),           &
 !!$          axis_ids=(/ ilon, ilat, ipres, itim /), &
@@ -357,7 +335,7 @@ PROGRAM ipcc_test_code
      IF (m.ne.3) THEN
         print*, 'itim axis ids: ',ilon,ilat,itim
         var2d_ids(m) = cmor_variable(    &
-             table='Tables/CMIP5_3hr',  &
+             table='Tables/CMIP6_3hr.json',  &
              table_entry=entry2d(m),     & 
              units=units2d(m),           & 
              axis_ids=(/ ilon, ilat, itim /), &
@@ -368,7 +346,7 @@ PROGRAM ipcc_test_code
      ELSE
         print*, 'itim1 axis ids: ',ilon,ilat,itim1
         var2d_ids(m) = cmor_variable(    &
-             table='Tables/CMIP5_3hr',  &
+             table='Tables/CMIP6_3hr.json',  &
              table_entry=entry2d(m),     & 
              units=units2d(m),           & 
              axis_ids=(/ ilon, ilat, itim1 /), &
