@@ -37,7 +37,7 @@ CONTAINS
     END DO
         plevs = (/100000., 92500., 85000., 70000.,&
        60000., 50000., 40000., 30000., 25000., 20000.,&
-       15000., 10000., 7000., 5000., 3000., 2000., 1000. /)
+       15000., 10000., 7000., 5000., 3000., 2000., 1000., 500., 100. /)
   
     RETURN
   END SUBROUTINE read_coords
@@ -111,10 +111,10 @@ PROGRAM ipcc_test_code
   INTEGER, PARAMETER :: lon = 4       ! number of longitude grid cells  
   INTEGER, PARAMETER :: lat = 3       ! number of latitude grid cells
   INTEGER, PARAMETER :: lev = 5       ! number of standard pressure levels
-  INTEGER, PARAMETER :: lev2 = 17       ! number of standard pressure levels
+  INTEGER, PARAMETER :: lev2 = 19       ! number of standard pressure levels
   INTEGER, PARAMETER :: n2d = 4       ! number of IPCC Table A1a fields to be
                                       !     output.
-  INTEGER, PARAMETER :: n3d = 4       ! number of IPCC Table A1c fields to 
+  INTEGER, PARAMETER :: n3d = 3       ! number of IPCC Table A1c fields to 
                                       !     be output.  
 
   !   Tables associating the user's variables with IPCC standard output 
@@ -128,14 +128,14 @@ PROGRAM ipcc_test_code
 
                                 ! My variable names for IPCC Table A1c fields
   CHARACTER (LEN=5), DIMENSION(n3d) :: &
-                                 varin3d=(/'CLOUD', 'tro3 ', 'U    ', 'T    '/)
+                                 varin3d=(/'CLOUD', 'U    ', 'T    '/)
 
                                 ! Units appropriate to my data
   CHARACTER (LEN=5), DIMENSION(n3d) :: &
-                                  units3d=(/ '%    ', '1e-9 ',  'm s-1',   'K    '  /)
+                                  units3d=(/ '%    ',  'm s-1',   'K    '  /)
 
                      ! Corresponding IPCC Table A1c entry (variable name) 
-  CHARACTER (LEN=4), DIMENSION(n3d) :: entry3d = (/ 'cl  ', 'tro3', 'ua  ', 'ta  ' /)
+  CHARACTER (LEN=4), DIMENSION(n3d) :: entry3d = (/ 'cl  ', 'ua  ', 'ta  ' /)
 
                                 ! My variable names for IPCC Table A1a fields
   CHARACTER (LEN=8), DIMENSION(n2d) :: &
@@ -214,34 +214,11 @@ PROGRAM ipcc_test_code
   !   experiment conditions, and provide information to be included as 
   !   attributes in all CF-netCDF files written as part of this dataset.
 
-  error_flag = cmor_dataset(                                   &
-       outpath='Test',                                         &
-       experiment_id='abrupt 4XCO2',           &
-       institution=                                            &
-       'GICC (Generic International Climate Center, ' //       &
-       'Geneva, Switzerland)',                                 &
-       source='GICCM1 (2002): ' //                             &
-       'atmosphere:  GICAM3 (gicam_0_brnchT_itea_2, T63L32); '// &
-       'ocean: MOM (mom3_ver_3.5.2, 2x3L15); '             //  &
-       'sea ice: GISIM4; land: GILSM2.5',                      &
-       calendar='360_day',                                      &
-       realization=1,                                          &
-       history='Output from archivcl_A1.nce/giccm_03_std_2xCO2_2256.', &
-       comment='Equilibrium reached after 30-year spin-up ' // &
-       'after which data were output starting with nominal '// &
-       'date of January 2030',                                 &
-       references='Model described by Koder and Tolkien ' //   &
-       '(J. Geophys. Res., 2001, 576-591).  Also '        //   &
-       'see http://www.GICC.su/giccm/doc/index.html '     //   &
-       ' 2XCO2 simulation described in Dorkey et al. '    //   &
-       '(Clim. Dyn., 2003, 323-357.)',model_id="GICCM1", &
-       forcing='TO',contact="Barry Bonds",institute_id="PCMDI",&
-       parent_experiment_rip="N/A",parent_experiment_id="N/A",branch_time=bt)
-
+  error_flag = cmor_dataset_json("Test/common_user_input.json")
   !  Define all axes that will be needed
   
   ilat = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -249,7 +226,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lat)        
       
   ilon2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',        &
+       table='Tables/CMIP6_Lmon.json',        &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
@@ -257,7 +234,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lon)      
         
   ilat2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',        &
+       table='Tables/CMIP6_Lmon.json',        &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
@@ -265,7 +242,7 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lat)        
       
   ilon = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
@@ -273,8 +250,8 @@ PROGRAM ipcc_test_code
        cell_bounds=bnds_lon)      
         
   ipres = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
-       table_entry='plevs',       &
+       table='Tables/CMIP6_Amon.json',        &
+       table_entry='plev19',       &
        units='Pa',                   &
        length=lev2,                   &
        coord_vals=plevs)
@@ -284,13 +261,13 @@ PROGRAM ipcc_test_code
   !   cmor_write (later, below).
 
   itim = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='time',           &
        units='days since 2030-1-1',  &
        length=ntimes,                &
        interval='1 month')
   itim2 = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',        &
+       table='Tables/CMIP6_Lmon.json',        &
        table_entry='time',           &
        units='days since 2030-1-1',  &
        length=ntimes,                &
@@ -301,7 +278,7 @@ PROGRAM ipcc_test_code
   zlev_bnds=(/ 0.,.2, .42, .62, .8, 1. /)
 
   ilev = cmor_axis(  &
-       table='Tables/CMIP5_Amon',        &
+       table='Tables/CMIP6_Amon.json',        &
        table_entry='standard_sigma',       &
 !!$       table_entry='standard_hybrid_sigma',       &
        units='1',&
@@ -344,7 +321,7 @@ PROGRAM ipcc_test_code
   !    (appearing in IPCC table A1c)
 
   var3d_ids(1) = cmor_variable(    &
-       table='Tables/CMIP5_Amon',      &
+       table='Tables/CMIP6_Amon.json',      &
        table_entry=entry3d(1),     &
        units=units3d(1),           &
        axis_ids=(/ ilev, ilon, ilat, itim /),  &
@@ -356,7 +333,7 @@ PROGRAM ipcc_test_code
   
   DO m=2,n3d
      var3d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',      &
+          table='Tables/CMIP6_Amon.json',      &
           table_entry=entry3d(m),     &
           units=units3d(m),           &
           axis_ids=(/ ipres, ilon, ilat, itim /), &
@@ -370,7 +347,7 @@ PROGRAM ipcc_test_code
   DO m=1,n2d
      if (m.ne.3) then
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Amon',      &
+          table='Tables/CMIP6_Amon.json',      &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
           axis_ids=(/ ilon, ilat, itim /), &
@@ -379,7 +356,7 @@ PROGRAM ipcc_test_code
           original_name=varin2d(m))   
   else
      var2d_ids(m) = cmor_variable(    &
-          table='Tables/CMIP5_Lmon',      &
+          table='Tables/CMIP6_Lmon.json',      &
           table_entry=entry2d(m),     & 
           units=units2d(m),           & 
           axis_ids=(/ ilon2, ilat2, itim2 /), &
